kdiagram.plot.evaluation.plot\_regression\_performance
======================================================

.. currentmodule:: kdiagram.plot.evaluation

.. autofunction:: plot_regression_performance